@@ -455,31 +455,31 @@ class Witter():
     def updateSelectedView(self, *args):
         #call the get method for whichever liststore we're viewing
         if (self.treeview.get_model() == self.liststore):
-            #self.getTweets()
-	    refreshtask = witter.RefreshTask(self.getTweetsWrapper, self.showBusy)
-	    refreshtask.refresh()
+				#self.getTweets()
+				refreshtask = witter.RefreshTask(self.getTweetsWrapper, self.showBusy)
+				refreshtask.refresh()
         elif (self.treeview.get_model() == self.dmliststore):
-            refreshtask = witter.RefreshTask(self.getDMsWrapper, self.showBusy)
-	    refreshtask.refresh()
+				refreshtask = witter.RefreshTask(self.getDMsWrapper, self.showBusy)
+				refreshtask.refresh()
         elif (self.treeview.get_model() == self.mentionliststore):
             
-	    refreshtask = witter.RefreshTask(self.getMentionsWrapper, self.showBusy)
-	    refreshtask.refresh()
+				refreshtask = witter.RefreshTask(self.getMentionsWrapper, self.showBusy)
+				refreshtask.refresh()
         elif (self.treeview.get_model() == self.publicliststore):
-            refreshtask = witter.RefreshTask(self.getPublicWrapper, self.showBusy)
-	    refreshtask.refresh()
+				refreshtask = witter.RefreshTask(self.getPublicWrapper, self.showBusy)
+				refreshtask.refresh()
         elif (self.treeview.get_model() == self.trendliststore):
-            refreshtask = witter.RefreshTask(self.getTrends, self.showBusy)
-	    refreshtask.refresh()
+				refreshtask = witter.RefreshTask(self.getTrends, self.showBusy)
+				refreshtask.refresh()
         elif (self.treeview.get_model() == self.friendsliststore):
-            refreshtask = witter.RefreshTask(self.getFriends, self.showBusy)
-	    refreshtask.refresh()
+				refreshtask = witter.RefreshTask(self.getFriends, self.showBusy)
+				refreshtask.refresh()
         elif (self.treeview.get_model() == self.searchliststore):
-            refreshtask = witter.RefreshTask(self.getSearchWrapper, self.showBusy)
-	    refreshtask.refresh()
+				refreshtask = witter.RefreshTask(self.getSearch, self.showBusy)
+				refreshtask.refresh()
 	
-	self.builder.get_object("hbox1").hide_all()
-	self.builder.get_object("hbox2").hide_all()
+	#self.builder.get_object("hbox1").hide_all()
+	#self.builder.get_object("hbox2").hide_all()
 	
             
     def getTweets(self, auto=0, *args):
@@ -725,77 +725,77 @@ class Witter():
 
             
     def getSearch(self, auto=0,*args):
-        print "performing search"
-	#clear any previous stuff, currenlty we'll just get one page of search results
-        self.searchliststore.clear()
-        #overloading the tweet text input as the search criteria
-        searchterm = self.builder.get_object("TweetText").get_text()
-        if (auto==1):
-		#auto search performed frrom the saved search
-		searchterm = self.search_terms
-		
-        #see if we have just an empty string (eg eroneous button press)
-        if (searchterm == ""):
-            print "nothing to search"
-            return
-        
-        
-        #split the tweet text on any comma , 
-	
-	searchTerms = searchterm.split(",")
-	#call search on each of the terms in the search str
-	for term in searchTerms:
-		term = unicode(term).encode('utf-8')
-		#then we need to urlencode so that we can use twitter chars like @ without
-		#causing problems
-		search = urllib.urlencode({ 'q' : term })
-		
-		#Now for the main logic...fetching tweets
-		#at the moment I'm just using basic auth. 
-		#urllib2 provides all the HTTP handling stuff
-		auth_handler = urllib2.HTTPBasicAuthHandler()
-		#realm here is important. or at least it seemed to be
-		#this info is on the login box if you go to the url in a browser
-		auth_handler.add_password(realm='Twitter API',
-				  uri=self.searchServiceUrlRoot+'/search.json',
-				  user=self.username,
-				  passwd=self.password)
-		#we create an 'opener' object with our auth_handler
-		opener = urllib2.build_opener(auth_handler)
-		# ...and install it globally so it can be used with urlopen.
-		urllib2.install_opener(opener)
-		
-		try:
-		    json = urllib2.urlopen(self.searchServiceUrlRoot+'search.json?'+search)
-		    
-		    #JSON is awesome stuff. we get given a long string of json encoded information
-		    #which contains all the tweets, with lots of info, we decode to a json object
-		    data = simplejson.loads(json.read())
-		    #then this line does all the hard work. Basicaly for evey top level object in the JSON
-		    #structure we call out getStatus method with the contents of the USER structure
-		    #and the values of top level values text/id/created_at
-	  
-		    results = data['results']
-		    [self.getStatus(x['from_user'],x['text'], x['id'], x['created_at'],None, None, "search") for x in results]
-		    note = osso.SystemNote(self.osso_c)
+		print "performing search"
+		#clear any previous stuff, currenlty we'll just get one page of search results
+		self.searchliststore.clear()
+		#overloading the tweet text input as the search criteria
+		searchterm = self.builder.get_object("TweetText").get_text()
+		if (auto==1):
+				#auto search performed frrom the saved search
+				searchterm = self.search_terms
 
-		    result = note.system_note_infoprint("Search results Received for : " + term)
-		except IOError, e:
-		    msg = 'Error retrieving search results '
-		    if hasattr(e, 'reason'):
-			    msg = msg + str(e.reason)
-			    
-		    if hasattr(e, 'code'):
-			if (e.code == 401):
-			    reason = "Not authorised: check uid/pwd"
-			elif(e.code == 503):
-			    reason = "Service unavailable"
-			else:
-			    reason = ""
-			msg = msg +'Server returned ' + str(e.code) + " : " + reason
-		    if (auto ==0):
-			    note = osso.SystemNote(self.osso_c)
-			    note.system_note_dialog(msg)
+		#see if we have just an empty string (eg eroneous button press)
+		if (searchterm == ""):
+			print "nothing to search"
+			return
+
+				
+		#split the tweet text on any comma , 
+
+		searchTerms = searchterm.split(",")
+		#call search on each of the terms in the search str
+		for term in searchTerms:
+				term = unicode(term).encode('utf-8')
+				#then we need to urlencode so that we can use twitter chars like @ without
+				#causing problems
+				search = urllib.urlencode({ 'q' : term })
+
+				#Now for the main logic...fetching tweets
+				#at the moment I'm just using basic auth. 
+				#urllib2 provides all the HTTP handling stuff
+				auth_handler = urllib2.HTTPBasicAuthHandler()
+				#realm here is important. or at least it seemed to be
+				#this info is on the login box if you go to the url in a browser
+				auth_handler.add_password(realm='Twitter API',
+						  uri=self.searchServiceUrlRoot+'/search.json',
+						  user=self.username,
+						  passwd=self.password)
+				#we create an 'opener' object with our auth_handler
+				opener = urllib2.build_opener(auth_handler)
+				# ...and install it globally so it can be used with urlopen.
+				urllib2.install_opener(opener)
+
+				try:
+					json = urllib2.urlopen(self.searchServiceUrlRoot+'search.json?'+search)
+					
+					#JSON is awesome stuff. we get given a long string of json encoded information
+					#which contains all the tweets, with lots of info, we decode to a json object
+					data = simplejson.loads(json.read())
+					#then this line does all the hard work. Basicaly for evey top level object in the JSON
+					#structure we call out getStatus method with the contents of the USER structure
+					#and the values of top level values text/id/created_at
+
+					results = data['results']
+					[self.getStatus(x['from_user'],x['text'], x['id'], x['created_at'],None, None, "search") for x in results]
+					note = osso.SystemNote(self.osso_c)
+
+					result = note.system_note_infoprint("Search results Received for : " + term)
+				except IOError, e:
+					msg = 'Error retrieving search results '
+					if hasattr(e, 'reason'):
+						msg = msg + str(e.reason)
+						
+					if hasattr(e, 'code'):
+							if (e.code == 401):
+								reason = "Not authorised: check uid/pwd"
+							elif(e.code == 503):
+								reason = "Service unavailable"
+							else:
+								reason = ""
+					msg = msg +'Server returned ' + str(e.code) + " : " + reason
+					if (auto ==0):
+						note = osso.SystemNote(self.osso_c)
+						note.system_note_dialog(msg)
 
 
             
@@ -1170,28 +1170,26 @@ class Witter():
         try:
             if select2 != None:
                 for item in select2[0]:
-                    #we want to access field 3 which has or Tweet in it
-                    entry = select1.get_value(select1.get_iter(item), 2)
-                    #and we might as well list the person who provided the url
-                    name = select1.get_value(select1.get_iter(item), 0)
-                    id = select1.get_value(select1.get_iter(item), 4)
-                    
-                if re.search("http", entry): 
-                    #convert the string to chunks deliniated on space (we assume the url 
-                    #has spaces around it 
-                    L = string.split(entry)
-                    for word in L :
-                        #find the 'word' which is our url
-                        if re.search("http", word):
-                            url=word
-                            menuUrls = gtk.Menu()
-                            menuItemLaunchURL = gtk.MenuItem(url)
-                            menuItemLaunchURL.connect("activate", self.openBrowser, url )
-                            menuUrls.append(menuItemLaunchURL)
-                            menuUrls.show()
-                            self.menuItemURL.set_submenu(menuUrls)
-                            
-                    
+						#we want to access field 3 which has or Tweet in it
+						entry = select1.get_value(select1.get_iter(item), 2)
+						#and we might as well list the person who provided the url
+						name = select1.get_value(select1.get_iter(item), 0)
+						id = select1.get_value(select1.get_iter(item), 4)
+						if re.search("http", entry): 
+								#convert the string to chunks deliniated on space (we assume the url 
+								#has spaces around it 
+								L = string.split(entry)
+								for word in L :
+									#find the 'word' which is our url
+									if re.search("http", word):
+										url=word
+										menuUrls = gtk.Menu()
+										menuItemLaunchURL = gtk.MenuItem(url)
+										menuItemLaunchURL.connect("activate", self.openBrowser, url )
+										menuUrls.append(menuItemLaunchURL)
+										menuUrls.show()
+										self.menuItemURL.set_submenu(menuUrls)
+  
                 menuUserAct = gtk.Menu()        
                 menuItemFollowUser = gtk.MenuItem("Follow: "+name)                 
                 menuItemFollowUser.connect("activate", self.FollowUser, name)
